==> cramr_ui_lib-1.0.2.tar.gz: test/widgets/coverable_textfield_test.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/widgets/coverable_textfield.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';

main() {
  test('test keybuilder for covers', () {
    const Key expectedKey = Key('coverkey_infinitive_1');
    expect(CoverableTextField.coverKey(_randomInfinitive, 1), expectedKey);
  });

  testWidgets('Test the workings of the cover toggle',
      (WidgetTester tester) async {
    VerbTestModel model = VerbTestModel();
    model.initialise(_randomIndicative, _randomPronouns, _randomInfinitive,
        'fr', 'translation');
    await tester.pumpWidget(ChangeNotifierProvider(
        create: (BuildContext buildContext) {
          return model;
        },
        child: const MaterialApp(home: CoverableTextField(person: 1))));
    Finder coverFinder =
        find.byKey(const Key('coverkey_${_randomInfinitive}_1'));
    Finder gestureDetectorFinder =
        find.byKey(const Key('cover_gesturedetector_${_randomInfinitive}_1'));
    Finder displayedTextFinder = find.text(model.expected[1]);
    expect(coverFinder, findsOneWidget);
    expect(displayedTextFinder, findsNothing);
    expect(gestureDetectorFinder, findsOneWidget);
    await tester.tap(gestureDetectorFinder);
    await tester.pump();
    expect(coverFinder, findsNothing);
    expect(displayedTextFinder, findsOneWidget);
  });
}

==> cramr_ui_lib-1.0.7.tar.gz: test/widgets/coverable_textfield_test.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/widgets/coverable_textfield.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';

main() {
  test('test keybuilder for covers', () {
    const Key expectedKey = Key('coverkey_infinitive_1');
    expect(CoverableTextField.coverKey(_randomInfinitive, 1), expectedKey);
  });

  testWidgets('Test the workings of the cover toggle',
      (WidgetTester tester) async {
    VerbTestModel model = VerbTestModel();
    model.initialise(_randomIndicative, _randomPronouns, _randomInfinitive,
        'fr', 'translation', 'mode', 'tense');
    await tester.pumpWidget(ChangeNotifierProvider(
        create: (BuildContext buildContext) {
          return model;
        },
        child: const MaterialApp(home: CoverableTextField(person: 1))));
    Finder coverFinder =
        find.byKey(const Key('coverkey_${_randomInfinitive}_1'));
    Finder gestureDetectorFinder =
        find.byKey(const Key('cover_gesturedetector_${_randomInfinitive}_1'));
    Finder displayedTextFinder = find.text(model.expected[1]);
    expect(coverFinder, findsOneWidget);
    expect(displayedTextFinder, findsNothing);
    expect(gestureDetectorFinder, findsOneWidget);
    await tester.tap(gestureDetectorFinder);
    await tester.pump();
    expect(coverFinder, findsNothing);
    expect(displayedTextFinder, findsOneWidget);
  });
}
